@@ -451,14 +451,13 @@ class SubParameter(unittest.TestCase):
         subscription = sub.subscribe(['fsdf'], 'group1', 100)
         self.assertTrue(subscription.get() is None)
 
-        subscription = sub.subscribe(['root/MyModule1/input1'], 'group1', 100)
+        subscription = sub.subscribe(['root/Control/dummyDouble'], 'group1', 100)
         self.assertTrue(subscription.get())
 
         subscription.notify(self.newValue)
         timestamp = 0
-        for x in range(4):
-            timestamp = subscription.read()[0].timestamp
-            print(timestamp)
+        for x in range(400):
+            print(f"timestamp: {subscription.read()[0].timestamp}, value: {subscription.read()[0].value}")
             time.sleep(1)
 
         self.assertTrue(sub.unsubscribe(subscription).get().status == motorcortex.OK)
